@@ -1,6 +1,7 @@
 /*
     SPDX-FileCopyrightText: 2001-2013 Evan Teran <evan.teran@gmail.com>
     SPDX-FileCopyrightText: 1996-2000 Bernd Johannes Wuebben <wuebben@kde.org>
+    SPDX-FileCopyrightText: 2022 Harald Sitter <sitter@kde.org>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -38,6 +39,7 @@ KCalcDisplay::KCalcDisplay(QWidget *parent)
     , history_index_(0)
     , selection_timer_(new QTimer(this))
 {
+    setAccessibleDescription(i18nc("@label accessibility description of the calculation result display", "Result Display"));
     setFocusPolicy(Qt::StrongFocus);
 
     setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed));
@@ -59,9 +61,7 @@ KCalcDisplay::KCalcDisplay(QWidget *parent)
 // Name: ~KCalcDisplay
 // Desc: destructor
 //------------------------------------------------------------------------------
-KCalcDisplay::~KCalcDisplay()
-{
-}
+KCalcDisplay::~KCalcDisplay() = default;
 
 //------------------------------------------------------------------------------
 // Name: changeSettings
@@ -595,9 +595,50 @@ void KCalcDisplay::setText(const QString &string)
     }
 
     update();
+    setAccessibleName(text_); // "Labels should be represented by only QAccessibleInterface and return their text as name"
     Q_EMIT changedText(text_);
 }
 
+//------------------------------------------------------------------------------
+// Name: setFont
+// Desc: Set the base font and recalculate the font size to better fit
+//------------------------------------------------------------------------------
+void KCalcDisplay::setFont(const QFont &font)
+{
+    // Overwrite current baseFont
+    baseFont_ = font;
+    updateFont();
+}
+
+//------------------------------------------------------------------------------
+// Name: updateFont
+// Desc: Update font using baseFont to better fit
+//------------------------------------------------------------------------------
+void KCalcDisplay::updateFont()
+{
+    // Make a working copy of the font
+    QFont* newFont = new QFont(baseFont());
+
+    // Calculate ideal font size
+    // constants arbitrarily chosen, adjust/increase if scaling issues arise
+    newFont->setPointSizeF(qMax(double(baseFont().pointSize()), qMin(contentsRect().height() / 4.5, contentsRect().width() / 24.6)));
+
+    // Apply font
+    QFrame::setFont(*newFont);
+    
+    // Free the memory
+    delete newFont;
+}
+
+//------------------------------------------------------------------------------
+// Name: baseFont
+// Desc:
+//------------------------------------------------------------------------------
+const QFont& KCalcDisplay::baseFont() const
+{
+    return baseFont_;
+}
+
 //------------------------------------------------------------------------------
 // Name: formatDecimalNumber
 // Desc: Convert decimal number to locale-dependent format.
@@ -1025,7 +1066,7 @@ void KCalcDisplay::paintEvent(QPaintEvent *)
     // draw the status texts using half of the normal
     // font size but not smaller than 7pt
     QFont fnt(font());
-    fnt.setPointSize(qMax((fnt.pointSize() / 2), 7));
+    fnt.setPointSizeF(qMax((fnt.pointSize() / 2.0), 7.0));
     painter.setFont(fnt);
 
     QFontMetrics fm(fnt);
@@ -1037,17 +1078,32 @@ void KCalcDisplay::paintEvent(QPaintEvent *)
     }
 }
 
+//------------------------------------------------------------------------------
+// Name: resizeEvent
+// Desc: resize display and adjust font size
+//------------------------------------------------------------------------------
+void KCalcDisplay::resizeEvent(QResizeEvent* event)
+{
+    QFrame::resizeEvent(event);
+
+    // Update font size
+    updateFont();
+}
+
 //------------------------------------------------------------------------------
 // Name: sizeHint
 // Desc:
 //------------------------------------------------------------------------------
 QSize KCalcDisplay::sizeHint() const
 {
+    // font metrics of base font
+    const QFontMetrics fmBase(baseFont());
+    
     // basic size
-    QSize sz = fontMetrics().size(Qt::TextSingleLine, text_);
+    QSize sz = fmBase.size(0, QStringLiteral("M"));
 
     // expanded by 3/4 font height to make room for the status texts
-    QFont fnt(font());
+    QFont fnt(baseFont());
     fnt.setPointSize(qMax(((fnt.pointSize() * 3) / 4), 7));
 
     const QFontMetrics fm(fnt);
