@@ -11,17 +11,13 @@
 // Name: KStats
 // Desc: constructor
 //------------------------------------------------------------------------------
-KStats::KStats()
-{
-}
+KStats::KStats() = default;
 
 //------------------------------------------------------------------------------
 // Name: ~KStats
 // Desc: destructor
 //------------------------------------------------------------------------------
-KStats::~KStats()
-{
-}
+KStats::~KStats() = default;
 
 //------------------------------------------------------------------------------
 // Name: clearAll
